#!/usr/bin/python3

"""
pyweek #27 Copyright (C) 2019 Paul Brownsea

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import sys
try:
    import pygame
    from pygame.locals import *
except ImportError:
    print ("Can't find pygame...")
    sys.exit(1)

pygame.init()

FPS = 24
SCREENWIDTH = 1024
SCREENHEIGHT = 768
BLACK = (0, 0, 0)
WHITE = (255, 255, 255)
BLUE = (0, 255, 0)

try:
    FONT16 = pygame.font.Font('freesansbold.ttf', 16)
    FONT32 = pygame.font.Font('freesansbold.ttf', 32)
except OSError:
    print ("Can't find font (freesansbold.ttf)...")
    sys.exit(1)
SCREEN = pygame.display.set_mode((SCREENWIDTH, SCREENHEIGHT), 0)
FPSCLOCK = pygame.time.Clock()

class digit:
  digit = 0

  def __init__(self):
    self.digit = 0

class Worker (pygame.sprite.Sprite):
  def __init__(self, x, y, cashpersec):
    pygame.sprite.Sprite.__init__(self)
    self.image = pygame.image.load('worker.png').convert()
    self.rect = self.image.get_rect()
    self.rect.x = x
    self.rect.y = y
    self.level = 1
    self.cashpersec = cashpersec
  def update (self):
    pass

class Motivater (pygame.sprite.Sprite):
    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        self.image = pygame.image.load('motivate.png').convert()
        self.rect = self.image.get_rect()
        self.rect.x = 700
        self.rect.y = 250
        self.frames=FPS//2
    def update(self):
        self.frames-=1
        if self.frames == 0:
            self.kill()

def doText (position, fgColour, bgColour, text, size):
  if size == 16:
    font = FONT16
  elif size == 32:
    font = FONT32
  else:
    print ("Unknown font size :(")
    sys.exit()
  txtsurf = font.render(text, True, fgColour, bgColour)
  txtrect = txtsurf.get_rect()
  if position [0] != None:
    txtrect.topleft = ((position [0], position [1]))
  else:
    txtrect.midtop = ((SCREENWIDTH / 2 ,position [1]))
  txt = SCREEN.blit(txtsurf, txtrect)
  return txt

prices={}
prices['x']=[50, 200, 350, 50, 200, 350]
prices['y']=[50, 50, 50, 200, 200, 200]
prices['m']=[10, 100, 1000, 10000, 100000, 1000000]
######

def titleScreen ():
    done = False
    redo = True
    while not done:
        if redo:
            SCREEN.blit (pygame.image.load('background_title.png').convert(), (0, 0))
            startButton = doText ((None, 100), BLACK, WHITE, "Start", 32)
            infoButton = doText ((None, 150), BLACK, WHITE, "Info", 32)
            quitButton = doText ((None, 200), BLACK, WHITE, "Quit", 32)
            pygame.display.update ()
            redo = False

        for event in pygame.event.get():
            if event.type == QUIT:
                sys.exit()
            elif event.type == MOUSEBUTTONDOWN:
                if quitButton.collidepoint (event.pos):
                    done = True
                elif startButton.collidepoint (event.pos):
                    doGame ()
                    redo = True
                elif infoButton.collidepoint (event.pos):
                    staticScreen ('info')
                    redo = True
        FPSCLOCK.tick (FPS)

def staticScreen (screen):
    done = False
    SCREEN.blit (pygame.image.load('background_' + screen + '.png').convert(), (0, 0))
    okButton = doText ((None, 600), BLACK, WHITE, "OK", 32)
    pygame.display.update ()
    while not done:
        for event in pygame.event.get():
            if event.type == QUIT:
                sys.exit()
            elif event.type == MOUSEBUTTONDOWN:
                if okButton.collidepoint (event.pos):
                    done = True
            elif event.type == pygame.KEYDOWN :
                if event.key == pygame.K_RETURN :
                    done = True
        FPSCLOCK.tick (FPS)

def doGame():
  workers = pygame.sprite.Group()
  motivate =  pygame.sprite.GroupSingle()

  money = 10
  framecount = 0
  done = False
  initialtime = pygame.time.get_ticks()
  cursor = 1
  cursor2 = 0
  BG = pygame.image.load('background_game.png').convert()
  while not done:
    #SCREEN.fill(WHITE)
    SCREEN.blit (BG, (0, 0))
    #pygame.display.flip()
    for event in pygame.event.get():
      if event.type == QUIT:
        sys.exit()
      elif event.type == pygame.KEYDOWN :
        if event.key == pygame.K_LEFT :
          cursor2 -= 1
        elif event.key == pygame.K_RIGHT :
          cursor2 += 1
        elif event.key == pygame.K_UP :
          cursor -= 1
        elif event.key == pygame.K_DOWN :
          cursor += 1
        elif event.key == pygame.K_RETURN :
          if cursor == 0:
            qty = len(workers)
            if qty < 6:
              x = prices['x'][qty]
              y = prices['y'][qty]
              m = prices['m'][qty]
              if money >= m:
                money -= m
                workers.add (Worker (x, y, m))
                cursor = 1
          elif cursor == 1:
            for worker in workers:
                money = money + worker.cashpersec
                motivate.add (Motivater())
          elif cursor == 2:
            pass
    if cursor < 0:
        cursor = 2
    elif cursor > 2:
        cursor = 0


    framecount = framecount + 1
    if framecount == FPS:
        framecount = 0
        for worker in workers:
            money = money + worker.cashpersec

    doText ((0, 0), BLACK, WHITE, str((pygame.time.get_ticks() - initialtime) / 1000), 32)
    doText ((200, 0), BLACK, WHITE, "£"+str(money), 32)

    msgcount = 0
    if len(workers) < 6:
      buy = " (" + str(prices['m'][len(workers)]) + ")";
    else:
      buy = " X"
    for message in ["Buy" + buy,"Motivate","Upgrade","..."]:
      if msgcount == cursor:
        c1 = WHITE
        c2 = BLACK
      else:
        c2 = WHITE
        c1 = BLACK
      doText ((50, 400 + (32 * msgcount)), c1, c2, message, 32)
      msgcount += 1

    motivate.update()
    motivate.draw(SCREEN)
    workers.update ()
    workers.draw(SCREEN)

    qty = len(workers)
    if qty > 0:
        if cursor2 < 0:
            cursor2 = qty - 1
        elif cursor2 >= qty:
            cursor2 = 0
        pygame.draw.rect(SCREEN, BLUE, pygame.Rect(prices['x'][cursor2], prices['y'][cursor2], 100, 100), 1)

    pygame.display.update ()

    FPSCLOCK.tick (FPS)

titleScreen()

pygame.quit()
sys.exit()
